{% extends 'layout.html' %}

{% block content %}
<div class="container" style="margin-top: 20px;">
    <h1 class="text-info">Single User Details</h1>
    <h2>User ID : {{user.id}}</h2>
    <h2>Name : {{user.name}}</h2>
    <h2>Email : {{user.email}}</h2>
    <h2>Password : {{user.password}}</h2>
    <h2>Mobile : {{user.mobile}}</h2>
</div>
{% endblock %}