{% extends 'layout.html' %}

{% block content %}
<div class="container" style="margin-top: 20px;">
    <h1>User Profile</h1>
    {% if request.session.user_email %}
        <h1>Successfully Login {{request.session.user_email}}</h1>
    {% endif %}
</div>
{% endblock %}