<!DOCTYPE html>
{% load static %}
<html lang="en">
<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">
    <title>DJango Website</title>
    <link rel="stylesheet" href="{% static 'css/bootstrap.min.css' %}">
    <script src="{% static 'js/jquery.slim.min.js' %}"></script>
    <script src="{% static 'js/popper.min.js' %}"></script>
    <script src="{% static 'js/bootstrap.min.js' %}"></script>
</head>
<body>
    <!--Header Start-->
    <nav class="navbar navbar-expand-lg navbar-dark bg-dark">
           <div class="container">
                <a class="navbar-brand" href="{% url 'home' %}">DJango</a>
                <button class="navbar-toggler" type="button" data-toggle="collapse" data-target="#navbarSupportedContent" aria-controls="navbarSupportedContent" aria-expanded="false" aria-label="Toggle navigation">
                  <span class="navbar-toggler-icon"></span>
                </button>
              
                <div class="collapse navbar-collapse" id="navbarSupportedContent">
                  <ul class="navbar-nav mr-auto">
                    <li class="nav-item">
                      <a class="nav-link" href="{% url 'home' %}">Home</a>
                    </li>
                    {% if request.session.user_email %}
                      <li class="nav-item">
                        <a class="nav-link" href="{% url 'profile' %}">Profile</a>
                        </li> 
                      <li class="nav-item">
                        <a class="nav-link" href="{% url 'allusers' %}">Users</a>
                      </li> 
                      <li class="nav-item">
                        <a class="nav-link" href="{% url 'logout' %}">Logout</a>
                      </li> 
                    {% else %}
                        <li class="nav-item">
                          <a class="nav-link" href="{% url 'login' %}">Login</a>
                        </li>
                        <li class="nav-item">
                          <a class="nav-link" href="{% url 'signup' %}">Signup</a>
                        </li> 
                    {% endif%}
                   
                    
                  </ul>
                  
                </div>
           </div>
          </nav>
    <!--Header End-->

    <!--Dynamic Child Page Start-->
    {% block content %}

    {% endblock %}
    <!--Dynamic Child Page End-->

    <!--Footer Start-->
    <hr>

    <footer>
        <div class="container">
            <p>Powered By DJango 2019 All Rights Reserved 2019</p>
        </div>
    </footer>
    <!--Footer End-->
</body>
</html>