{% extends 'layout.html' %}

{% block content %}
<div class="container" style="margin-top: 20px">
    <div class="row">
        <div class="col-md-4">
            {% if msg %}
                <div class="alert alert-{{tag}}">{{msg}}</div>
            {% endif %}
            <div class="card">
                <div class="card-header">
                    <h5 class="card-title">Signup Form</h5>
                </div>
                <div class="card-body">
                    <form action="{% url 'signup' %}" method="POST">
                    {% csrf_token %}
                        <div class="form-group">
                            <label>Name</label>
                            <input type="text" placeholder="Full Name" class="form-control" name="name" required>
                        </div>
                        <div class="form-group">
                            <label>Email</label>
                            <input type="email" placeholder="Email" class="form-control" name="email" required>
                        </div>
                        <div class="form-group">
                            <label>Password</label>
                            <input type="password" placeholder="Password" class="form-control" name="password" required>
                        </div>
                        <div class="form-group">
                            <label>Mobile</label>
                            <input type="number" placeholder="Mobile" class="form-control" name="mobile" required>
                        </div>
                        <div class="form-group">
                            <button type="submit" class="btn btn-success">Signup</button>
                        </div>
                    </form>
                </div>
                <div class="card-footer">
                    Existing Users Login <a href="{% url 'login' %}">Here</a>
                </div>
            </div>
        </div>
        <div class="col-md-8">

        </div>
    </div>
</div>
{% endblock %}